DialoguewiseService class
Allows you to manage your content using Dialoguewise Headless CMS
Constructors
- DialoguewiseService({String? apiBaseUrl, required String accessToken})
Properties
- accessToken → String
-
final
- apiBaseUrl → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addContents(
AddContentsRequest request) → Future< DialoguewiseResponse> -
Adds content to a dialogue.
Takes
requestof type AddContentsRequest. -
deleteContent(
DeleteContentRequest request) → Future< DialoguewiseResponse> -
Delete exisitng content.
Takes
requestof type DeleteContentRequest. -
getContents(
GetContentsRequest request) → Future< DialoguewiseResponse> -
Gets all the contents in a dialogue.
Takes parameter
requestof type GetContentsRequest. -
getDialogues(
) → Future< DialoguewiseResponse> - Gets all the published Dialogues in a project. Returns a DialoguewiseResponse object. Example:
-
getVariables(
GetVariablesRequest request) → Future< DialoguewiseResponse> -
Gets all the Variables of a published Dialogue.
Takes parameter
requestof type GetVariablesRequest. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
searchContents(
SearchContentsRequest request) → Future< DialoguewiseResponse> -
Gets all the contents in a dialogue that matches the search keyword.
Takes
requestof type SearchContentsRequest. -
sendEmail(
EmailRequest request) → Future< DialoguewiseResponse> -
Allows you to send an email.
Takes
requestof type EmailRequest. -
toString(
) → String -
A string representation of this object.
inherited
-
updateContent(
UpdateContentRequest request) → Future< DialoguewiseResponse> -
Update exisitng content.
Takes
requestof type UpdateContentRequest. -
uploadMedia(
String fileName, List< int> fileData, String mimeType) → Future<DialoguewiseResponse> -
Uploads an image or file and returns the file URL.
Takes
fileNameas the name of the file. TakesfileDataas the file binary data. TakesmimeTypeas the mime type. Throws ArgumentError if the file data is empty. Throws ArgumentError if the mime type is empty. -
uploadMediaByPath(
String filePath) → Future< DialoguewiseResponse> -
Uploads an image or file given file path and returns the URL of uploaded file.
Takes
filePathwhich is the path to the local file. Throws ArgumentError if the file path is empty. Throws FileSystemException if the file does not exist.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited